==> knowledge-center-api-0.0.5.1-sources.jar: cn/yoofans/knowledge/center/api/param/order/CreateOrderParam.java <==
package cn.yoofans.knowledge.center.api.param.order;

import java.io.Serializable;
import java.util.List;

import org.apache.commons.lang3.builder.ToStringBuilder;

import cn.yoofans.knowledge.center.api.dto.order.OrderItemDto;

/**
 * 创建订单参数
 * Created by sunyan on 2018/4/11.
 */
public class CreateOrderParam implements Serializable {

    private static final long serialVersionUID = 7944034356264425944L;

    private Integer amount;//订单金额

    private Long consumerId;//买家ID

    private String consumerName;//买家名称

    private Long authorizerId;//小程序ID

    private String orderType;//订单类型

    private List<OrderItemDto> OrderItems;//购买商品

    private Long moduleId; // 埋点数据 模块ID

    private String originUrl; // 埋点数据 来源URL

    private Long readStageId; // 阅读期数ID

    public Integer getAmount() {
        return amount;
    }

    public void setAmount(Integer amount) {
        this.amount = amount;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public String getConsumerName() {
        return consumerName;
    }

    public void setConsumerName(String consumerName) {
        this.consumerName = consumerName;
    }

    public Long getAuthorizerId() {
        return authorizerId;
    }

    public void setAuthorizerId(Long authorizerId) {
        this.authorizerId = authorizerId;
    }

    public String getOrderType() {
        return orderType;
    }

    public void setOrderType(String orderType) {
        this.orderType = orderType;
    }

    public List<OrderItemDto> getOrderItems() {
        return OrderItems;
    }

    public void setOrderItems(List<OrderItemDto> orderItems) {
        OrderItems = orderItems;
    }

    public Long getModuleId() {
        return moduleId;
    }

    public void setModuleId(Long moduleId) {
        this.moduleId = moduleId;
    }

    public String getOriginUrl() {
        return originUrl;
    }

    public void setOriginUrl(String originUrl) {
        this.originUrl = originUrl;
    }

    public Long getReadStageId() {
        return readStageId;
    }

    public void setReadStageId(Long readStageId) {
        this.readStageId = readStageId;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}

==> knowledge-center-api-0.2.0-dev-20180731.032829-1-sources.jar: cn/yoofans/knowledge/center/api/param/order/CreateOrderParam.java <==
package cn.yoofans.knowledge.center.api.param.order;

import java.io.Serializable;
import java.util.List;

import org.apache.commons.lang3.builder.ToStringBuilder;

import cn.yoofans.knowledge.center.api.dto.order.OrderItemDto;

/**
 * 创建订单参数
 * Created by sunyan on 2018/4/11.
 */
public class CreateOrderParam implements Serializable {

    private static final long serialVersionUID = 7944034356264425944L;

    private Integer amount;//订单金额

    private Long consumerId;//买家ID

    private String consumerName;//买家名称

    private Long authorizerId;//小程序ID

    private String orderType;//订单类型

    private List<OrderItemDto> orderItems;//购买商品

    private Long moduleId; // 埋点数据 模块ID

    private String originUrl; // 埋点数据 来源URL

    private Long readStageId; // 阅读期数ID

    private String url;// 埋点数据 下单URL

    private String couponId;//优惠券ID

    public Integer getAmount() {
        return amount;
    }

    public void setAmount(Integer amount) {
        this.amount = amount;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public String getConsumerName() {
        return consumerName;
    }

    public void setConsumerName(String consumerName) {
        this.consumerName = consumerName;
    }

    public Long getAuthorizerId() {
        return authorizerId;
    }

    public void setAuthorizerId(Long authorizerId) {
        this.authorizerId = authorizerId;
    }

    public String getOrderType() {
        return orderType;
    }

    public void setOrderType(String orderType) {
        this.orderType = orderType;
    }

    public List<OrderItemDto> getOrderItems() {
        return orderItems;
    }

    public void setOrderItems(List<OrderItemDto> orderItems) {
        this.orderItems = orderItems;
    }

    public Long getReadStageId() {
        return readStageId;
    }

    public void setReadStageId(Long readStageId) {
        this.readStageId = readStageId;
    }

    public Long getModuleId() {
        return moduleId;
    }

    public void setModuleId(Long moduleId) {
        this.moduleId = moduleId;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public String getOriginUrl() {
        return originUrl;
    }

    public void setOriginUrl(String originUrl) {
        this.originUrl = originUrl;
    }

    public String getCouponId() {
        return couponId;
    }

    public void setCouponId(String couponId) {
        this.couponId = couponId;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }

}
